@@ -17,9 +17,6 @@
 	    _i_vector-ref
 	    _i_mutable-vector-ref
 	    _i_mutable-vector-set!
-	    _i_value-vector-ref
-	    _i_mutable-value-vector-ref
-	    _i_mutable-value-vector-set!
 	    _b_vector-length
 	    theme-string-match
 	    integer->real
@@ -27,7 +24,6 @@
 	    theme-truncate
 	    theme-floor
 	    theme-ceiling
-	    xor
 	    theme-real-integer/
 	    real-to-rational-impl
 	    theme-open-output-file
@@ -80,16 +76,23 @@
 
 
 (eval-when (expand load eval)
-	   (import (only (rnrs) assert)))
+           (use-modules ((rnrs) #:select (assert))))
 
-(import (except (rnrs) map))
-(import (srfi srfi-1))
-(import (ice-9 regex))
-(import (oop goops))
+(use-modules (rnrs exceptions))
+(use-modules (rnrs conditions))
+(use-modules (rnrs base))
+(use-modules (rnrs lists))
+(use-modules (rnrs io ports))
+(use-modules (srfi srfi-1))
+(use-modules (ice-9 regex))
+(use-modules (oop goops))
+
+(use-modules (th-scheme-utilities stdutils))
+(use-modules (theme-d runtime theme-d-support))
+(use-modules (theme-d runtime runtime-theme-d-environment))
+(use-modules (theme-d runtime rte-base))
+(use-modules (theme-d runtime rte-globals))
 
-(import (th-scheme-utilities stdutils))
-(import (theme-d runtime runtime-theme-d-environment))
-(import (theme-d runtime theme-d-support))
 
 (define (raise-simple s-kind)
   (raise (make-theme-d-condition s-kind '())))
@@ -142,36 +145,21 @@
   (theme-d-condition-info exc))
 
 
-(define (_i_vector-ref uv i)
-  (vector-ref uv (+ i 1)))
+(define (_i_vector-ref vec i)
+  (vector-ref (slot-ref vec 'v-field-values) i))
 
 
 (define (_i_mutable-vector-ref vec i)
-  (vector-ref vec (+ i 1)))
+  (vector-ref (slot-ref vec 'v-field-values) i))
 
 
 (define (_i_mutable-vector-set! vec i item)
   ;; The result of this procedure is undefined.
-  (vector-set! vec (+ i 1) item))
-
-
-(define (_i_value-vector-ref vec i)
-  (vector-ref vec (+ i 1)))
-
-
-(define (_i_mutable-value-vector-ref vec i)
-  (vector-ref vec (+ i 1)))
-
-
-(define (_i_mutable-value-vector-set! vec i item)
-  (vector-set! vec (+ i 1) item))
+  (vector-set! (slot-ref vec 'v-field-values) i item))
 
 
 (define (_b_vector-length vec)
-  ;; The first element of a vector is its class.
-  (let ((raw-len (vector-length vec)))
-    (assert (> raw-len 0))
-    (- raw-len 1)))
+  (vector-length (slot-ref vec 'v-field-values)))
 
 
 (define (theme-string-match str-pattern str-source)
@@ -214,12 +202,6 @@
   (real->integer (r-ceiling r)))
 
 
-(define xor
-  (lambda (b1 b2)
-    (or (and b1 (not b2))
-	(and (not b1) b2))))
-
-
 (define (theme-real-integer/ r n)
   (if (= n 0)
       ;; guile-2.2 returns +-inf in this case, too.
@@ -258,12 +240,12 @@
     result))
 
 
-(define (theme-with-exception-handler type-result proc-handler proc-body)
+(define (theme-with-exception-handler proc-handler proc-body)
   (with-exception-handler
    (lambda (variable)
-     (_i_call-proc proc-handler (list variable) (list _b_<object>)))
+     (_i_call-simple-proc proc-handler (list variable)))
    (lambda ()
-     (_i_call-proc proc-body '() '()))))
+     (_i_call-simple-proc proc-body '()))))
 
 
 ;; *** (standard-library math) ***
@@ -564,10 +546,8 @@
 
 
 (define (reverse-search-goops-class clas)
-  (let ((l-desc (hashq-ref gl-ht-goops-classes clas)))
-    (if (not (eq? l-desc #f))
-	(car l-desc)
-	#f)))
+  (hashq-ref gl-ht-goops-classes clas))
+
 
 (define (reverse-get-goops-class clas)
   (let ((o (reverse-search-goops-class clas)))
