@@ -42,13 +42,17 @@
 
 
 (define (is-tuple-type? binder to)
+  (d2wl 'debug1064 "is-tuple-type?")
+  (d2wl 'debug1064 (debug-get-string to))
   (and
    (is-target-object? to)
    ;; The following test should not be strictly necessary.
    (not (eqv? to '()))
    (or (target-type=? to tc-nil)
        (and (is-tc-pair? to)
+            (begin (d2wl 'debug1064 "is-tuple-type?/1") #t)
             (is-type? binder (tt-car to))
+            (begin (d2wl 'debug1064 "is-tuple-type?/2") #t)
             (is-tuple-type? binder (tt-cdr to))))))
 
 
@@ -423,6 +427,10 @@
          (new-inst-type (cadr new-components))
          (new-arg-list (tno-field-ref new-inst-type 'type-arglist))
          (new-result-type (tno-field-ref new-inst-type 'type-result)))
+    (d2wl 'cowb-param-proc-class "cowb-param-proc-class/1")
+    (d2wl 'cowb-param-proc-class (debug-get-string new-tvars))
+    (d2wl 'cowb-param-proc-class (debug-get-string new-arg-list))
+    (d2wl 'cowb-param-proc-class (debug-get-string new-result-type))
     (if (for-all is-t-type-variable? new-tvars)
       (if (and (eqv? (length old-tvars) (length new-tvars))
                ;; and-map? returns #t for empty list
